@@ -170,15 +170,18 @@ GBLtranslators =
 "Jiri Huf\n"
 "- cs (Czech) translation of ISO Master version 1.3\n"
 "\n"
-"Toni Graffy\n"
-"- de (German) translation of ISO Master versions 0.6 - 1.3\n"
-"\n"
 "Magnus Valle\n"
 "- da (Danish) translation of ISO Master version 1.3\n"
 "\n"
 "Henrik Kristiansen\n"
 "- da (Danish) translation of ISO Master version 1.3\n"
 "\n"
+"Toni Graffy\n"
+"- de (German) translation of ISO Master versions 0.6 - 1.3\n"
+"\n"
+"Daniel Schury\n"
+"- de (German) translation of ISO Master version 1.3\n"
+"\n"
 "Mike Kranidis\n"
 "- el (Greek) translation of ISO Master versions 1.1 - 1.3\n"
 "\n"
@@ -227,6 +230,9 @@ GBLtranslators =
 "Valerio Guaglianone\n"
 "- it (Italian) translation of ISO Master version 0.7, 1.1, 1.3\n"
 "\n"
+"Hajime Taira\n"
+"- ja (Japanese) translation of ISO Master version 1.3\n"
+"\n"
 "Rihards Prieditis\n"
 "- lv (Latvian) translation of ISO Master version 1.3\n"
 "\n"
@@ -284,6 +290,10 @@ GBLtranslators =
 "Serhey Kusyumoff\n"
 "- uk (Ukrainian) translation of ISO Master versions 0.8, 1.3\n"
 "\n"
+"Muhammad Ali Makki\n"
+"http://makki.urducoder.com/\n"
+"- ur (Urdu) translation of ISO Master version 1.3\n"
+"\n"
 "Sun Minchao\n"
 "- zh_CN (Simplified Chineese) translation of ISO Master version 0.7 - 1.3\n"
 "\n"
